/****************************************************************************
** Meta object code from reading C++ file 'qvirtualkeyboarddictionarymanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtvirtualkeyboard/src/virtualkeyboard/qvirtualkeyboarddictionarymanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvirtualkeyboarddictionarymanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto QVirtualKeyboardDictionaryManager::qt_create_metaobjectdata<qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVirtualKeyboardDictionaryManager",
        "availableDictionariesChanged",
        "",
        "baseDictionariesChanged",
        "extraDictionariesChanged",
        "activeDictionariesChanged",
        "availableDictionaries",
        "baseDictionaries",
        "extraDictionaries",
        "activeDictionaries"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'availableDictionariesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'baseDictionariesChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extraDictionariesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeDictionariesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'availableDictionaries'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'baseDictionaries'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'extraDictionaries'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'activeDictionaries'
        QtMocHelpers::PropertyData<QStringList>(9, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVirtualKeyboardDictionaryManager, qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QVirtualKeyboardDictionaryManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t>.metaTypes,
    nullptr
} };

void QVirtualKeyboardDictionaryManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QVirtualKeyboardDictionaryManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->availableDictionariesChanged(); break;
        case 1: _t->baseDictionariesChanged(); break;
        case 2: _t->extraDictionariesChanged(); break;
        case 3: _t->activeDictionariesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QVirtualKeyboardDictionaryManager::*)()>(_a, &QVirtualKeyboardDictionaryManager::availableDictionariesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVirtualKeyboardDictionaryManager::*)()>(_a, &QVirtualKeyboardDictionaryManager::baseDictionariesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVirtualKeyboardDictionaryManager::*)()>(_a, &QVirtualKeyboardDictionaryManager::extraDictionariesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVirtualKeyboardDictionaryManager::*)()>(_a, &QVirtualKeyboardDictionaryManager::activeDictionariesChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->availableDictionaries(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->baseDictionaries(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->extraDictionaries(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->activeDictionaries(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setBaseDictionaries(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setExtraDictionaries(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QVirtualKeyboardDictionaryManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVirtualKeyboardDictionaryManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33QVirtualKeyboardDictionaryManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QVirtualKeyboardDictionaryManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QVirtualKeyboardDictionaryManager::availableDictionariesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QVirtualKeyboardDictionaryManager::baseDictionariesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QVirtualKeyboardDictionaryManager::extraDictionariesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QVirtualKeyboardDictionaryManager::activeDictionariesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
